@@ -374,6 +374,7 @@ void ActionManager::initViewMenuActions()
 	scrActions->insert("viewFit75", new ScrAction(ScrAction::DataDouble, QIconSet(), "", QKeySequence(), ScMW, "viewFit75", 0, 75.0));
 	scrActions->insert("viewFit100", new ScrAction(ScrAction::DataDouble, QIconSet(), "", CTRL+Key_1, ScMW, "viewFit100", 0, 100.0));
 	scrActions->insert("viewFit200", new ScrAction(ScrAction::DataDouble, QIconSet(), "", QKeySequence(), ScMW, "viewFit200", 0, 200.0));
+	scrActions->insert("viewFit400", new ScrAction(ScrAction::DataDouble, QIconSet(), "", QKeySequence(), ScMW, "viewFit400", 0, 400.0));
 	scrActions->insert("viewFit20", new ScrAction(ScrAction::DataDouble, QIconSet(), "", QKeySequence(), ScMW, "viewFit20", 0, 20.0));
 	scrActions->insert("viewShowMargins", new ScrAction(ScMW, "viewShowMargins"));
 	scrActions->insert("viewShowFrames", new ScrAction(ScMW, "viewShowFrames"));
@@ -417,6 +418,7 @@ void ActionManager::initViewMenuActions()
 	connect( (*scrActions)["viewFit75"], SIGNAL(activatedData(double)), ScMW, SLOT(slotZoom(double)) );
 	connect( (*scrActions)["viewFit100"], SIGNAL(activatedData(double)), ScMW, SLOT(slotZoom(double)) );
 	connect( (*scrActions)["viewFit200"], SIGNAL(activatedData(double)), ScMW, SLOT(slotZoom(double)) );
+	connect( (*scrActions)["viewFit400"], SIGNAL(activatedData(double)), ScMW, SLOT(slotZoom(double)) );
 	connect( (*scrActions)["viewFit20"], SIGNAL(activatedData(double)), ScMW, SLOT(slotZoom(double)) );
 	connect( (*scrActions)["viewShowMargins"], SIGNAL(activated()), ScMW, SLOT(ToggleMarks()) );
 	connect( (*scrActions)["viewShowFrames"], SIGNAL(activated()), ScMW, SLOT(ToggleFrames()) );
@@ -519,12 +521,12 @@ void ActionManager::initToolsMenuActions()
 
 void ActionManager::initExtrasMenuActions()
 {
-	scrActions->insert("extrasManagePictures", new ScrAction(ScMW, "extrasManagePictures"));
+	scrActions->insert("extrasManageImages", new ScrAction(ScMW, "extrasManageImages"));
 	scrActions->insert("extrasHyphenateText", new ScrAction(ScMW, "extrasHyphenateText"));
 	scrActions->insert("extrasDeHyphenateText", new ScrAction(ScMW, "extrasDeHyphenateText"));
 	scrActions->insert("extrasGenerateTableOfContents", new ScrAction(ScMW, "extrasGenerateTableOfContents"));
 
-	connect( (*scrActions)["extrasManagePictures"], SIGNAL(activated()), ScMW, SLOT(StatusPic()) );
+	connect( (*scrActions)["extrasManageImages"], SIGNAL(activated()), ScMW, SLOT(StatusPic()) );
 	connect( (*scrActions)["extrasGenerateTableOfContents"], SIGNAL(activated()), ScMW, SLOT(generateTableOfContents()) );
 }
 
@@ -564,6 +566,9 @@ void ActionManager::initUnicodeActions(QMap<QString, QGuardedPtr<ScrAction> > *a
 	actionMap->insert("unicodeNonBreakingHyphen", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", CTRL+ALT+Key_Minus, actionParent, "unicodeNonBreakingHyphen",24));
 	actionMap->insert("unicodeNonBreakingSpace", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", CTRL+Key_Space, actionParent, "unicodeNonBreakingSpace",29));
 	actionMap->insert("unicodePageNumber", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", CTRL+SHIFT+ALT+Key_P, actionParent, "unicodePageNumber",30));
+	actionMap->insert("unicodeApostrophe", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeApostrophe",0x2019));
+//	actionMap->insert("unicodePrime", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodePrime",0x2032));
+//	actionMap->insert("unicodeDoublePrime", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeDoublePrime",0x2033));
 	//Spaces
 	actionMap->insert("unicodeSpaceEN", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeSpaceEN",0x2002));
 	actionMap->insert("unicodeSpaceEM", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeSpaceEM",0x2003));
@@ -588,8 +593,9 @@ void ActionManager::initUnicodeActions(QMap<QString, QGuardedPtr<ScrAction> > *a
 	actionMap->insert("unicodeDashFigure", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeDashFigure",0x2012));
 	actionMap->insert("unicodeDashQuotation", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeDashQuotation",0x2015));
 	//Quotes
-	actionMap->insert("unicodeQuoteApostrophe", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteApostrophe",0x0027));
-	actionMap->insert("unicodeQuoteStraight", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteStraight",0x0022));
+//	actionMap->insert("unicodeQuoteSingleStraight", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteSingleStraight",0x0027)); // spark
+	actionMap->insert("unicodeQuoteApostrophe", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteApostrophe",0x0027)); // spark // deprecated, s.a.
+	actionMap->insert("unicodeQuoteStraight", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteStraight",0x0022)); // rabbit-ears
 	actionMap->insert("unicodeQuoteSingleLeft", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteSingleLeft",0x2018));
 	actionMap->insert("unicodeQuoteSingleRight", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteSingleRight",0x2019));
 	actionMap->insert("unicodeQuoteDoubleLeft", new ScrAction(ScrAction::UnicodeChar, QIconSet(), "", QKeySequence(), actionParent, "unicodeQuoteDoubleLeft",0x201C));
@@ -618,6 +624,7 @@ void ActionManager::initUnicodeActions(QMap<QString, QGuardedPtr<ScrAction> > *a
 	//Spaces and special characters
 	*actionNamesList << "unicodeSmartHyphen" << "unicodeNonBreakingHyphen" << "unicodeNonBreakingSpace" << "unicodePageNumber";
 	*actionNamesList << "unicodeSpaceEN" << "unicodeSpaceEM" << "unicodeSpaceThin" << "unicodeSpaceThick" << "unicodeSpaceMid" << "unicodeSpaceHair";
+	*actionNamesList << "unicodeApostrophe"; // << "unicodePrime" << "unicodeDoublePrime";
 	//Breaks
 	*actionNamesList << "unicodeNewLine" << "unicodeFrameBreak" << "unicodeColumnBreak";
 	//Copyrights and TMs
@@ -629,7 +636,7 @@ void ActionManager::initUnicodeActions(QMap<QString, QGuardedPtr<ScrAction> > *a
 	//Dashes
 	*actionNamesList << "unicodeDashEm" << "unicodeDashEn" << "unicodeDashFigure" << "unicodeDashQuotation";
 	//Straight quotes
-	*actionNamesList << "unicodeQuoteApostrophe" << "unicodeQuoteStraight";
+	*actionNamesList << "unicodeQuoteApostrophe" << "unicodeQuoteStraight"; // deprecated, use "unicodeQuoteSingleStraight"
 	//Double quotes
 	*actionNamesList << "unicodeQuoteDoubleLeft" << "unicodeQuoteDoubleRight" << "unicodeQuoteSingleLeft" << "unicodeQuoteSingleRight";
 	//Alternative single quotes
@@ -996,6 +1003,7 @@ void ActionManager::languageChange()
 	(*scrActions)["viewFit75"]->setTexts( tr("&75%"));
 	(*scrActions)["viewFit100"]->setTexts( tr("&100%"));
 	(*scrActions)["viewFit200"]->setTexts( tr("&200%"));
+	(*scrActions)["viewFit400"]->setTexts( tr("&400%"));
 	(*scrActions)["viewFit20"]->setTexts( tr("&Thumbnails"));
 	(*scrActions)["viewShowMargins"]->setTexts( tr("Show &Margins"));
 	(*scrActions)["viewShowFrames"]->setTexts( tr("Show &Frames"));
@@ -1059,7 +1067,7 @@ void ActionManager::languageChange()
 	(*scrActions)["toolsInsertFreehandLine"]->setText( tr("Insert Freehand Line"));
 
 	//Extras Menu
-	(*scrActions)["extrasManagePictures"]->setTexts( tr("&Manage Pictures"));
+	(*scrActions)["extrasManageImages"]->setTexts( tr("&Manage Images"));
 	(*scrActions)["extrasHyphenateText"]->setTexts( tr("&Hyphenate Text"));
 	(*scrActions)["extrasDeHyphenateText"]->setTexts( tr("Dehyphenate Text"));
 	(*scrActions)["extrasGenerateTableOfContents"]->setTexts( tr("&Generate Table Of Contents"));
@@ -1103,7 +1111,11 @@ void ActionManager::languageChangeUnicodeActions(QMap<QString, QGuardedPtr<ScrAc
 	(*actionMap)["unicodeDashFigure"]->setTexts( tr("Figure Dash"));
 	(*actionMap)["unicodeDashQuotation"]->setTexts( tr("Quotation Dash"));
 
-	(*actionMap)["unicodeQuoteApostrophe"]->setTexts( tr("Apostrophe"));
+	(*actionMap)["unicodeApostrophe"]->setTexts( tr("Apostrophe"));
+//	(*actionMap)["unicodePrime"]->setTexts( tr("Prime"));
+//	(*actionMap)["unicodeDoublePrime"]->setTexts( tr("Double Prime"));
+//	(*actionMap)["unicodeQuoteSingleStraight"]->setTexts( tr("Straight Apostrophe"));
+	(*actionMap)["unicodeQuoteApostrophe"]->setTexts( tr("Apostrophe")); // deprecated
 	(*actionMap)["unicodeQuoteStraight"]->setTexts( tr("Straight Double"));
 	(*actionMap)["unicodeQuoteSingleLeft"]->setTexts( tr("Single Left"));
 	(*actionMap)["unicodeQuoteSingleRight"]->setTexts( tr("Single Right"));
