@@ -52,47 +52,7 @@ for which a new license (GPL+exception) is in place.
 #include "prefsmanager.h"
 #include "scpaths.h"
 
-/*
-extern "C"
-{
-#define XMD_H           // shut JPEGlib up
-#if defined(Q_OS_UNIXWARE)
-#  define HAVE_BOOLEAN  // libjpeg under Unixware seems to need this
-#endif
-#include <jpeglib.h>
-#include <jerror.h>
-#undef HAVE_STDLIB_H
-#ifdef const
-#  undef const          // remove crazy C hackery in jconfig.h
-#endif
-}
-*/
 #include "scribus.h"
-/*
-#include <ft2build.h>
-#include FT_FREETYPE_H
-#include FT_OUTLINE_H
-#include FT_GLYPH_H
-#ifdef HAVE_TIFF
-	#include <tiffio.h>
-#endif
-#ifdef HAVE_CMS
-	#include CMS_INC
-extern cmsHPROFILE CMSoutputProf;
-extern cmsHPROFILE CMSprinterProf;
-extern cmsHTRANSFORM stdTransG;
-extern cmsHTRANSFORM stdProofG;
-extern cmsHTRANSFORM stdTransImgG;
-extern cmsHTRANSFORM stdProofImgG;
-extern bool BlackPoint;
-extern bool SoftProofing;
-extern bool Gamut;
-extern bool CMSuse;
-extern int IntentMonitor;
-extern int IntentPrinter;
-#endif
-*/
-
 #include "util.h"
 
 using namespace std;
@@ -275,13 +235,18 @@ QString getGSVersion()
 bool getNumericGSVersion(int & major, int & minor)
 {
 	QString gs_ver_string(getGSVersion());
+	return getNumericGSVersion(gs_ver_string, major, minor);
+}
+
+bool getNumericGSVersion(const QString& ver, int& major, int& minor)
+{
 	// gs's version string is of the form MAJOR.MINOR, so look for the .
 	// then convert to numbers. 7.07 will become (7,7) for example.
 	bool success = false;
-	major = gs_ver_string.section('.', 0, 0).toInt(&success);
+	major = ver.section('.', 0, 0).toInt(&success);
 	if (!success)
 		return false;
-	minor = gs_ver_string.section('.', 1, 1).toInt(&success);
+	minor = ver.section('.', 1, 1).toInt(&success);
 	if (!success)
 		return false;
 	return true;
@@ -291,67 +256,113 @@ QString getGSDefaultExeName(void)
 {
 	QString gsName;
 #if defined _WIN32
-	// Try to locate GhostScript thanks to the registry
-	DWORD size;
-	HKEY hKey;
-	LONG retValue;
-	DWORD regType = REG_SZ;
-	char regVersion[MAX_PATH];
-	char regPath[MAX_PATH];
-	char gsPath[MAX_PATH];
-
 	// Set gsName to its default value
 	gsName = "gswin32c.exe";
 
-	// Search AFPL Ghostscript first as it has more chance to be up to date
-	if( RegOpenKey(HKEY_LOCAL_MACHINE, "SOFTWARE\\AFPL Ghostscript", &hKey) == ERROR_SUCCESS )
-		strcpy(regPath, "SOFTWARE\\AFPL Ghostscript");
-	else if( RegOpenKey(HKEY_LOCAL_MACHINE, "SOFTWARE\\GPL Ghostscript", &hKey) == ERROR_SUCCESS )
-		strcpy(regPath, "SOFTWARE\\GPL Ghostscript");
+	QMap<int, QString> gplGS  = getGSExePaths("SOFTWARE\\GPL Ghostscript");
+	QMap<int, QString> afplGS = getGSExePaths("SOFTWARE\\AFPL Ghostscript");
+
+	QMap<int, QString> gsVersions;
+	QMap<int, QString>::ConstIterator it, itEnd;
+	for (it = afplGS.constBegin(); it != afplGS.constEnd(); ++it)
+		gsVersions.insert(it.key(), it.data());
+	for (it = gplGS.constBegin(); it != gplGS.constEnd(); ++it)
+		gsVersions.insert(it.key(), it.data());
+
+	if (gsVersions.isEmpty())
+		return gsName;
+
+	int currentVer = 0;
+	QString gsPath;
+	for (it = gsVersions.constBegin(); it != gsVersions.constEnd(); ++it)
+	{
+		int version = it.key();
+		if (version > currentVer)
+		{
+			gsPath = it.data();
+			QFileInfo fInfo(gsPath);
+			if (fInfo.exists())
+			{
+				gsName = gsPath;
+				currentVer = version;
+			}
+		}
+	}
+
+#elif defined(Q_OS_MAC)
+	QFileInfo bundleExe("/Library/Frameworks/Ghostscript/bin/gsc");
+	if (bundleExe.exists())
+		gsName = bundleExe.absFilePath();
 	else
-		return gsName;
-
-	// Search the first SubKey corresponding to the version key
-	size = sizeof(regVersion) - 1;
-	retValue = RegEnumKeyEx(hKey, 0, regVersion, &size, NULL, NULL, NULL, NULL);
-	RegCloseKey(hKey);
-	if( retValue != ERROR_SUCCESS )
-		return gsName;
-
-	strcat(regPath, "\\");
-	strcat(regPath, regVersion);
-
-	// Get the GS_DLL Value
-	if (RegOpenKey(HKEY_LOCAL_MACHINE, regPath, &hKey) != ERROR_SUCCESS)
-          return gsName;
-	size = sizeof(gsPath) - 1;
-	retValue = RegQueryValueEx(hKey, "GS_DLL", 0, &regType, (LPBYTE) gsPath, &size);
-	RegCloseKey(hKey);
-	if( retValue != ERROR_SUCCESS )
-		return gsName;
-
-	// We now have GhostScript dll path, but we want gswin32c.exe
-	// Normally gswin32c.exe and gsdll.dll are in the same directory
-	gsName = gsPath;
-	size = gsName.findRev("\\");
-	if(size <= 0)
-		return QString("gswin32c.exe");
-	gsName = gsName.left(size + 1);
-	gsName += "gswin32c.exe";
-
-	// Check GhostScript executable existence.
-	QFileInfo fInfo(gsName);
-	if( fInfo.exists() )
-		gsName.replace("\\", "/"); // Return a qt-styled path
-	else
-		gsName = "gswin32c.exe";
-
+		gsName = "gs";
 #else
 	gsName = "gs";
 #endif
 	return gsName;
 }
 
+QMap<int, QString> SCRIBUS_API getGSExePaths(const char* regKey)
+{
+	QMap<int, QString> gsVersions;
+#if defined _WIN32
+	// Try to locate GhostScript thanks to the registry
+	DWORD size;
+	HKEY hKey1, hKey2;
+	DWORD regType = REG_SZ;
+	char regVersion[MAX_PATH];
+	char regPath[MAX_PATH];
+	char gsPath[MAX_PATH];
+	QString gsVersion, gsName;
+
+	if( RegOpenKey(HKEY_LOCAL_MACHINE, regKey, &hKey1) == ERROR_SUCCESS )
+	{
+		size = sizeof(regVersion) - 1;
+		DWORD keyIndex = 0;
+		while ( RegEnumKeyEx(hKey1, keyIndex, regVersion, &size, NULL, NULL, NULL, NULL) == ERROR_SUCCESS )
+		{
+			int gsNumericVer, gsMajor, gsMinor;
+			strcpy(regPath, regKey);
+			strcat(regPath, "\\");
+			strcat(regPath, regVersion);
+			if (RegOpenKey(HKEY_LOCAL_MACHINE, regPath, &hKey2) == ERROR_SUCCESS)
+			{
+				size = sizeof(gsPath) - 1;
+				if (RegQueryValueEx(hKey2, "GS_DLL", 0, &regType, (LPBYTE) gsPath, &size) == ERROR_SUCCESS)
+				{
+					// We now have GhostScript dll path, but we want gswin32c.exe
+					// Normally gswin32c.exe and gsdll.dll are in the same directory
+					if ( getNumericGSVersion(QString(regVersion), gsMajor, gsMinor) )
+					{
+						gsNumericVer = gsMajor * 1000 + gsMinor;
+						gsName = gsPath;
+						size   = gsName.findRev("\\");
+						if (size > 0)
+						{
+							gsName  = gsName.left(size + 1);
+							gsName += "gswin32c.exe";
+							gsName.replace("\\", "/");
+							gsVersions.insert(gsNumericVer, gsName);
+						}	
+					}	
+				}
+				RegCloseKey(hKey2);
+			}
+			keyIndex++;
+		}
+		RegCloseKey(hKey1);
+	}
+#else
+	int gsNumericVer, gsMajor, gsMinor;
+	PrefsManager* prefsManager=PrefsManager::instance();
+	if (getNumericGSVersion(gsMajor, gsMinor))
+	{
+		gsNumericVer = gsMajor * 1000 + gsMinor;
+		gsVersions.insert(gsNumericVer, prefsManager->ghostscriptExecutable());
+	}
+#endif
+	return gsVersions;
+}
+
 QPixmap LoadPDF(QString fn, int Page, int Size, int *w, int *h)
 {
 	QString tmp, cmd1, cmd2;
@@ -362,10 +373,10 @@ QPixmap LoadPDF(QString fn, int Page, int Size, int *w, int *h)
 	tmp.setNum(Page);
 	QStringList args;
 	args.append("-r72");
-	args.append("-sOutputFile=\""+tmpFile+"\"");
+	args.append("-sOutputFile="+tmpFile);
 	args.append("-dFirstPage="+tmp);
 	args.append("-dLastPage="+tmp);
-	args.append("\""+pdfFile+"\"");
+	args.append(pdfFile);
 	ret = callGS(args);
 	if (ret == 0)
 	{
