@@ -187,9 +187,19 @@ SVGPlug::SVGPlug( QString fName, int flags ) :
 	unsupported = false;
 	Conversion = 0.8;
 	interactive = (flags & LoadSavePlugin::lfInteractive);
-	QString f = "";
+	QCString f;
+	bool isCompressed = false;
+	QByteArray bb(3), fa;
+	QFile fi(fName);
+	if (fi.open(IO_ReadOnly))
+	{
+		fi.readBlock(bb.data(), 2);
+		fi.close();
+		if ((bb[0] == QChar(0x1F)) && (bb[1] == QChar(0x8B)))
+			isCompressed = true;
+	}
 #ifdef HAVE_LIBZ
-	if(fName.right(2) == "gz")
+	if ((fName.right(2) == "gz") || (isCompressed))
 	{
 		gzFile gzDoc;
 		char buff[4097];
@@ -205,11 +215,14 @@ SVGPlug::SVGPlug( QString fName, int flags ) :
 		gzclose(gzDoc);
 	}
 	else
-		loadText(fName, &f);
+		loadRawText(fName, f);
 #else
-	loadText(fName, &f);
+	loadRawText(fName, f);
 #endif
-	if(!inpdoc.setContent(f))
+	fa.setRawData(f.data(), f.length());
+	bool svgLoadSucceed = inpdoc.setContent(fa);
+	fa.resetRawData(f.data(), f.length());
+	if (!svgLoadSucceed)
 		return;
 	m_gc.setAutoDelete( true );
 	QString CurDirP = QDir::currentDirPath();
@@ -261,8 +274,7 @@ void SVGPlug::convert(int flags)
 	ScMW->ScriptRunning = true;
 	qApp->setOverrideCursor(QCursor(waitCursor), true);
 	gc->Family = currDoc->toolSettings.defFont;
-	if (!currDoc->PageColors.contains("Black"))
-		currDoc->PageColors.insert("Black", ScColor(0, 0, 0, 255));
+	currDoc->PageColors.ensureBlackAndWhite();
 	m_gc.push( gc );
 	viewTransformX = 0;
 	viewTransformY = 0;
@@ -270,20 +282,23 @@ void SVGPlug::convert(int flags)
 	viewScaleY = 1;
 	if( !docElem.attribute( "viewBox" ).isEmpty() )
 	{
-		QWMatrix matrix;
-		QSize wh2 = parseWidthHeight(docElem, 1.0);
-		double w2 = wh2.width();
-		double h2 = wh2.height();
-		addGraphicContext();
 		QString viewbox( docElem.attribute( "viewBox" ) );
 		QStringList points = QStringList::split( ' ', viewbox.replace( QRegExp(","), " ").simplifyWhiteSpace() );
-		viewTransformX = points[0].toDouble();
-		viewTransformY = points[1].toDouble();
-		viewScaleX = w2 / points[2].toDouble();
-		viewScaleY = h2 / points[3].toDouble();
-		matrix.translate(viewTransformX, viewTransformY);
-		matrix.scale(viewScaleX, viewScaleY);
-		m_gc.current()->matrix = matrix;
+		if (points.size() > 3)
+		{
+			QWMatrix matrix;
+			QSize wh2 = parseWidthHeight(docElem, 1.0);
+			double w2 = wh2.width();
+			double h2 = wh2.height();
+			addGraphicContext();
+			viewTransformX = points[0].toDouble();
+			viewTransformY = points[1].toDouble();
+			viewScaleX = w2 / points[2].toDouble();
+			viewScaleY = h2 / points[3].toDouble();
+			matrix.translate(viewTransformX, viewTransformY);
+			matrix.scale(viewScaleX, viewScaleY);
+			m_gc.current()->matrix = matrix;
+		}
 	}
 	QPtrList<PageItem> Elements = parseGroup( docElem );
 	currDoc->m_Selection->clear();
@@ -357,7 +372,12 @@ void SVGPlug::setupTransform( const QDomElement &e )
 bool SVGPlug::isIgnorableNode( const QDomElement &e )
 {
 	QString nodeName(e.tagName());
-	if (nodeName == "metadata" || nodeName.contains("sodipodi") || nodeName.contains("inkscape"))
+	return isIgnorableNodeName(nodeName);
+}
+
+bool SVGPlug::isIgnorableNodeName( const QString &n )
+{
+	if (n.startsWith("sodipodi") || n.startsWith("inkscape") || n == "metadata")
 		return true;
 	return false;
 }
@@ -429,11 +449,14 @@ QRect SVGPlug::parseViewBox(const QDomElement &e)
 	{
 		QString viewbox( e.attribute( "viewBox" ) );
 		QStringList points = QStringList::split( ' ', viewbox.replace( QRegExp(","), " ").simplifyWhiteSpace() );
-		double left = points[0].toDouble();
-		double bottom  = points[1].toDouble();
-		double width = points[2].toDouble();
-		double height = points[3].toDouble();
-		box.setCoords((int) left, (int) bottom, (int) (left + width), (int) (bottom + height));
+		if (points.size() > 3)
+		{
+			double left = points[0].toDouble();
+			double bottom  = points[1].toDouble();
+			double width = points[2].toDouble();
+			double height = points[3].toDouble();
+			box.setCoords((int) left, (int) bottom, (int) (left + width), (int) (bottom + height));
+		}
 	}
 	return box;
 }
@@ -450,7 +473,14 @@ void SVGPlug::parseDefs(const QDomElement &e)
 		if (!svgStyle.Display) 
 			continue;
 		QString STag2 = b.tagName();
-		if ( STag2 == "linearGradient" || STag2 == "radialGradient" )
+		if ( STag2 == "g" )
+		{
+			QString id = b.attribute("id", "");
+			if (!id.isEmpty())
+				m_nodeMap.insert(id, b);
+			parseDefs(b);
+		}
+		else if ( STag2 == "linearGradient" || STag2 == "radialGradient" )
 			parseGradient( b );
 		else if ( b.hasAttribute("id") )
 		{
@@ -551,6 +581,11 @@ QPtrList<PageItem> SVGPlug::parseElement(const QDomElement &e)
 		GElements = parseSwitch(e);
 		return GElements;
 	}
+	else if( STag == "symbol" )
+	{
+		GElements = parseSymbol(e);
+		return GElements;
+	}
 	else if( e.tagName() == "use" )
 	{
 		GElements = parseUse(e);
@@ -733,7 +768,7 @@ QPtrList<PageItem> SVGPlug::parseElement(const QDomElement &e)
 		ImgClip.resize(0);
 		ite->Clip = FlattenPath(ite->PoLine, ite->Segments);
 	}
-	else
+	else if( !isIgnorableNodeName(STag) )
 	{
 		// warn if unsupported SVG feature
 		qDebug("%s", QString("Unsupported SVG Feature: %1").arg(STag).ascii());
@@ -865,8 +900,7 @@ QPtrList<PageItem> SVGPlug::parseText(const QDomElement &e)
 	QDomNode c = e.firstChild();
 	//double x = e.attribute( "x" ).isEmpty() ? 0.0 : parseUnit(e.attribute("x"));
 	//double y = e.attribute( "y" ).isEmpty() ? 0.0 : parseUnit(e.attribute("y"));
-	FPoint p = parseTextPosition(e);
-	double x = p.x(), y = p.y();
+	FPoint currentPos = parseTextPosition(e);
 	if ((!c.isNull()) && (c.toElement().tagName() == "tspan"))
 	{
 		for(QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
@@ -877,7 +911,7 @@ QPtrList<PageItem> SVGPlug::parseText(const QDomElement &e)
 			parseStyle(gc, tspan);
 			if (!gc->Display)
 				continue;
-			QPtrList<PageItem> el = parseTextElement(x, y, tspan);
+			QPtrList<PageItem> el = parseTextElement(tspan, currentPos);
 			for (uint ec = 0; ec < el.count(); ++ec)
 				GElements.append(el.at(ec));
 			delete( m_gc.pop() );
@@ -886,14 +920,14 @@ QPtrList<PageItem> SVGPlug::parseText(const QDomElement &e)
 	else
 	{
 		SvgStyle *gc = m_gc.current();
-		QPtrList<PageItem> el = parseTextElement(x, y, e);
+		QPtrList<PageItem> el = parseTextElement(e, currentPos);
 		for (uint ec = 0; ec < el.count(); ++ec)
 			GElements.append(el.at(ec));
 	}
 	return GElements;
 }
 
-QPtrList<PageItem> SVGPlug::parseTextElement(double x, double y, const QDomElement &e)
+QPtrList<PageItem> SVGPlug::parseTextElement(const QDomElement &e, FPoint& currentPos)
 {
 	ScText *hg;
 	QPtrList<PageItem> GElements;
@@ -903,7 +937,7 @@ QPtrList<PageItem> SVGPlug::parseTextElement(double x, double y, const QDomEleme
 	int desc = fontMetrics.descent();
 	double BaseX = currDoc->currentPage->xOffset();
 	double BaseY = currDoc->currentPage->yOffset();
-	QString Text = QString::fromUtf8(e.text()).stripWhiteSpace();
+	QString Text = e.text().simplifyWhiteSpace();
 	QDomNode c = e.firstChild();
 	if ( e.tagName() == "tspan" && e.text().isNull() )
 			Text = " ";
@@ -911,8 +945,8 @@ QPtrList<PageItem> SVGPlug::parseTextElement(double x, double y, const QDomEleme
 	double maxWidth = 0, maxHeight = 0;
 	double tempW = 0, tempH = 0;
 	SvgStyle *gc = m_gc.current();
-	int ity = (e.tagName() == "tspan") ? y : (y - qRound(gc->FontSize / 10.0));
-	int z = currDoc->itemAdd(PageItem::TextFrame, PageItem::Unspecified, x, ity, 10, 10, gc->LWidth, CommonStrings::None, gc->FillCol, true);
+	int ity = (e.tagName() == "tspan") ? currentPos.y() : (currentPos.y() - qRound(gc->FontSize / 10.0));
+	int z = currDoc->itemAdd(PageItem::TextFrame, PageItem::Unspecified, currentPos.x(), ity, 10, 10, gc->LWidth, CommonStrings::None, gc->FillCol, true);
 	PageItem* ite = currDoc->Items->at(z);
 	ite->setTextToFrameDist(0.0, 0.0, 0.0, 0.0);
 	ite->setLineSpacing(gc->FontSize / 10.0 + 2);
@@ -923,8 +957,8 @@ QPtrList<PageItem> SVGPlug::parseTextElement(double x, double y, const QDomEleme
 	double scaley = sqrt(mm.m21() * mm.m21() + mm.m22() * mm.m22());
 	if( (!e.attribute("x").isEmpty()) && (!e.attribute("y").isEmpty()) )
 	{
-		FPoint p = parseTextPosition(e);
-		double x1 = p.x(), y1 = p.y();
+		currentPos = parseTextPosition(e);
+		double x1 = currentPos.x(), y1 = currentPos.y();
 		double mx = mm.m11() * x1 + mm.m21() * y1 + mm.dx();
 		double my = mm.m12() * x1 + mm.m22() * y1 + mm.dy();
 		ite->setXPos(mx + BaseX);
@@ -932,8 +966,8 @@ QPtrList<PageItem> SVGPlug::parseTextElement(double x, double y, const QDomEleme
 	}
 	else
 	{
-		double mx = mm.m11() * x + mm.m21() * y + mm.dx();
-		double my = mm.m12() * x + mm.m22() * y + mm.dy();
+		double mx = mm.m11() * currentPos.x() + mm.m21() * currentPos.y() + mm.dx();
+		double my = mm.m12() * currentPos.x() + mm.m22() * currentPos.y() + mm.dy();
 		ite->setXPos(mx + BaseX);
 		ite->setYPos(my + BaseY);
 	}
@@ -994,12 +1028,8 @@ QPtrList<PageItem> SVGPlug::parseTextElement(double x, double y, const QDomEleme
 		tempH  = RealCHeight(currDoc, hg->cfont, hg->ch, hg->csize)+1;
 		maxWidth  = (tempW > maxWidth) ? tempW : maxWidth;
 		maxHeight = (tempH > maxHeight) ? tempH : maxHeight;
-		if (hg->ch == QChar(13))
-		{
-			ite->setWidthHeight(QMAX(ite->width(), tempW), ite->height() + ite->lineSpacing()+desc);
-			tempW = 0;
-		}
 	}
+	currentPos.setX( currentPos.x() + maxWidth );
 	double xpos = ite->xPos();
 	double ypos = ite->yPos();
 	ite->setWidthHeight(QMAX(ite->width(), maxWidth), QMAX(ite->height(), maxHeight));
@@ -1103,6 +1133,15 @@ QPtrList<PageItem> SVGPlug::parseSwitch(const QDomElement &e)
 	return SElements;
 }
 
+QPtrList<PageItem> SVGPlug::parseSymbol(const QDomElement &e)
+{
+	QPtrList<PageItem> SElements;
+	QString id = e.attribute(id);
+	if( !id.isEmpty() )
+		m_nodeMap.insert(id, e);
+	return SElements;
+}
+
 QPtrList<PageItem> SVGPlug::parseUse(const QDomElement &e)
 {
 	QPtrList<PageItem> UElements;
@@ -1120,39 +1159,43 @@ QDomElement SVGPlug::getNodeFromUseElement(const QDomElement &e)
 	it = m_nodeMap.find(href);
 	if (it != m_nodeMap.end())
 	{
-		QString attrName;
-		QDomNode clone = it.data().cloneNode();
-		QDomNamedNodeMap attributes = e.attributes();
-		ret = clone.toElement();
-		for (uint i = 0; i < attributes.count(); ++i)
+		// Transform use element to group
+		ret = e.cloneNode().toElement();
+		ret.setTagName("g");
+		if( ret.hasAttribute("x") || ret.hasAttribute("y") )
 		{
-			QDomAttr attr = attributes.item(i).toAttr();
-			attrName = attr.name();
-			if (attrName == "transform")
-			{
-				QString trans = attr.value();
-				if (ret.hasAttribute("transform"))
-					trans += QString(" %1").arg(ret.attribute("transform"));
-				ret.setAttribute(attr.name(), trans);
-			}
-			else if (attrName == "xlink:href")
-				continue;
-			else
-				ret.setAttribute(attr.name(), attr.value());
+			QString xAtt  = ret.attribute("x", "0.0");
+			QString yAtt  = ret.attribute("y", "0.0");
+			QString trans = ret.attribute("transform", "");
+			trans += QString(" translate(%1, %2)").arg(xAtt).arg(yAtt);
+			ret.setAttribute("transform", trans);
 		}
+		ret.removeAttribute("x");
+		ret.removeAttribute("y");
+		ret.removeAttribute("width");
+		ret.removeAttribute("height");
+		ret.removeAttribute("xlink:href");
+		QDomNode clone = it.data().cloneNode();
+		QDomElement cloneElm = clone.toElement();
+		if( cloneElm.tagName() == "symbol" )
+			cloneElm.setTagName("g"); // later fix to be svg
+		ret.appendChild(cloneElm);
 	}
 	return ret;
 }
 
 double SVGPlug::fromPercentage( const QString &s )
 {
-	if (s.endsWith( "%" ))
+	QString s1 = s;
+	if (s1.endsWith( ";" ))
+		s1 = s1.left(s1.length() - 1);
+	if (s1.endsWith( "%" ))
 	{
-		QString s1 = s.left(s.length() - 1);
+		s1 = s1.left(s1.length() - 1);
 		return s1.toDouble() / 100.0;
 	}
 	else
-		return s.toDouble();
+		return s1.toDouble();
 }
 
 double SVGPlug::parseUnit(const QString &unit)
@@ -1789,7 +1832,10 @@ QString SVGPlug::parseColor( const QString &s )
 	{
 		QString rgbColor = s.stripWhiteSpace();
 		if( rgbColor.startsWith( "#" ) )
+		{
+			rgbColor = rgbColor.left(7);
 			c.setNamedColor( rgbColor );
+		}
 		else
 			c = parseColorN( rgbColor );
 	}
@@ -1799,12 +1845,13 @@ QString SVGPlug::parseColor( const QString &s )
 	QColor tmpR;
 	for (it = currDoc->PageColors.begin(); it != currDoc->PageColors.end(); ++it)
 	{
-		currDoc->PageColors[it.key()].getRGB(&r, &g, &b);
+		it.data().getRGB(&r, &g, &b);
 		tmpR.setRgb(r, g, b);
-		if (c == tmpR && currDoc->PageColors[it.key()].getColorModel() == colorModelRGB)
+		if (c == tmpR && it.data().getColorModel() == colorModelRGB)
 		{
 			ret = it.key();
 			found = true;
+			break;
 		}
 	}
 	if (!found)
@@ -2000,7 +2047,7 @@ void SVGPlug::parsePA( SvgStyle *obj, const QString &command, const QString &par
 		obj->FontSize = static_cast<int>(parseUnit(params) * 10.0);
 	else if( command == "text-anchor" )
 		obj->textAnchor = params;
-	else
+	else if( !isIgnorableNodeName(command) )
 		unsupported = true;
 }
 
@@ -2036,6 +2083,8 @@ void SVGPlug::parseStyle( SvgStyle *obj, const QDomElement &e )
 		parsePA( obj, "stroke-opacity", e.attribute( "stroke-opacity" ) );
 	/*	if( !e.attribute( "stroke-miterlimit" ).isEmpty() )
 			parsePA( obj, "stroke-miterlimit", e.attribute( "stroke-miterlimit" ) );   */
+	if( !e.attribute( "fill-rule" ).isEmpty() )
+		parsePA( obj, "fill-rule", e.attribute( "fill-rule" ) );
 	if( !e.attribute( "fill-opacity" ).isEmpty() )
 		parsePA( obj, "fill-opacity", e.attribute( "fill-opacity" ) );
 	if( !e.attribute( "opacity" ).isEmpty() )
@@ -2112,7 +2161,7 @@ void SVGPlug::parseGradient( const QDomElement &e )
 	gradhelper.gradient.setRepeatMethod( VGradient::none );
 
 	QString href = e.attribute("xlink:href").mid(1);
-	double x1, y1, x2, y2;
+	double x1 = 0, y1 = 0, x2 = 1, y2 = 0;
 	if (!href.isEmpty())
 	{
 		if (m_gradients.contains(href))
